@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -28,6 +28,8 @@ if platform.system() == 'Windows':
 # local import
 from base.indiClass import IndiClass
 from base.alpacaClass import AlpacaClass
+from base.sgproClass import SGProClass
+from base.ninaClass import NINAClass
 from gui.utilities import toolsQtWidget
 from gui.widgets.devicePopup_ui import Ui_DevicePopup
 
@@ -43,7 +45,9 @@ class DevicePopup(toolsQtWidget.MWidget):
         'indi': 'INDI / INDIGO',
         'ascom': 'ASCOM',
         'alpaca': 'ALPACA',
-        'astrometry': 'ASTROMETRY',
+        'sgpro': 'SGPro',
+        'nina': 'N.I.N.A.',
+        'astrometry': 'astrometry',
         'astap': 'ASTAP',
         'onlineWeather': 'Online Weather',
         'relay': 'Relay',
@@ -84,13 +88,18 @@ class DevicePopup(toolsQtWidget.MWidget):
             'alpaca': {
                 'hostaddress': self.ui.alpacaHostAddress,
                 'port': self.ui.alpacaPort,
-                'deviceList': self.ui.alpacaDeviceList,
                 'user': self.ui.alpacaUser,
                 'password': self.ui.alpacaPassword,
             },
             'ascom': {
                 'deviceName': self.ui.ascomDevice,
             },
+            'sgpro': {
+                'deviceList': self.ui.sgproDeviceList,
+            },
+            'nina': {
+                'deviceList': self.ui.ninaDeviceList,
+            },
             'astrometry': {
                 'deviceList': self.ui.astrometryDeviceList,
                 'searchRadius': self.ui.astrometrySearchRadius,
@@ -120,6 +129,8 @@ class DevicePopup(toolsQtWidget.MWidget):
         self.ui.ok.clicked.connect(self.storeConfig)
         self.ui.indiDiscover.clicked.connect(self.discoverIndiDevices)
         self.ui.alpacaDiscover.clicked.connect(self.discoverAlpacaDevices)
+        self.ui.sgproDiscover.clicked.connect(self.discoverSGProDevices)
+        self.ui.ninaDiscover.clicked.connect(self.discoverNINADevices)
         self.ui.selectAstrometryIndexPath.clicked.connect(self.selectAstrometryIndexPath)
         self.ui.selectAstrometryAppPath.clicked.connect(self.selectAstrometryAppPath)
         self.ui.selectAstapIndexPath.clicked.connect(self.selectAstapIndexPath)
@@ -141,25 +152,19 @@ class DevicePopup(toolsQtWidget.MWidget):
         """
         firstFramework = next(iter(self.data['frameworks']))
         framework = self.data.get('framework')
-
         if not framework:
             framework = firstFramework
 
-        frameworkTabText = self.framework2tabs[framework]
         frameworkTabTextList = [self.framework2tabs[x] for x in self.data['frameworks']]
-
-        tabWidget = self.ui.tab.findChild(QWidget, frameworkTabText)
+        tabWidget = self.ui.tab.findChild(QWidget, framework)
         tabIndex = self.ui.tab.indexOf(tabWidget)
         self.ui.tab.setCurrentIndex(tabIndex)
 
         for index in range(0, self.ui.tab.count()):
             if self.ui.tab.tabText(index) in frameworkTabTextList:
                 self.ui.tab.setTabEnabled(index, True)
-
             else:
                 self.ui.tab.setTabEnabled(index, False)
-
-            # self.ui.tab.setStyleSheet(self.getStyle())
         return True
 
     def populateTabs(self):
@@ -200,7 +205,7 @@ class DevicePopup(toolsQtWidget.MWidget):
         """
         :return: True for test purpose
         """
-        self.setWindowTitle(f'Setup for: {self.deviceType}')
+        self.setWindowTitle(f'Setup driver for {self.deviceType}')
         self.selectTabs()
         self.populateTabs()
         return True
@@ -218,9 +223,7 @@ class DevicePopup(toolsQtWidget.MWidget):
         frameworkData = self.data['frameworks'][framework]
 
         for element in list(frameworkData):
-
             ui = self.framework2gui[framework].get(element)
-
             if isinstance(ui, QComboBox):
                 frameworkData['deviceName'] = ui.currentText()
                 frameworkData[element].clear()
@@ -230,21 +233,15 @@ class DevicePopup(toolsQtWidget.MWidget):
             elif isinstance(ui, QLineEdit):
                 if isinstance(frameworkData[element], str):
                     frameworkData[element] = ui.text()
-
                 elif isinstance(frameworkData[element], int):
                     frameworkData[element] = int(ui.text())
-
                 else:
                     frameworkData[element] = float(ui.text())
 
             elif isinstance(ui, QCheckBox):
                 frameworkData[element] = ui.isChecked()
-
             elif isinstance(ui, QDoubleSpinBox):
                 frameworkData[element] = ui.value()
-
-            else:
-                self.log.debug(f'Element {element} in gui for framework {framework} not found')
         return True
 
     def readFramework(self):
@@ -356,6 +353,82 @@ class DevicePopup(toolsQtWidget.MWidget):
         self.updateAlpacaDeviceNameList(deviceNames=deviceNames)
         return True
 
+    def updateSGProDeviceNameList(self, deviceNames=[]):
+        """
+        updateSGProDeviceNameList updates the indi device name selectors
+        combobox with the discovered entries. therefore it deletes the old list
+        and rebuild it new.
+
+        :return: True for test purpose
+        """
+        self.ui.sgproDeviceList.clear()
+        self.ui.sgproDeviceList.setView(QListView())
+        for deviceName in deviceNames:
+            self.ui.sgproDeviceList.addItem(deviceName)
+        return True
+
+    def discoverSGProDevices(self):
+        """
+        discoverSGProDevices looks all possible alpaca devices up from the
+        actual server and the selected device type.
+
+        :return: success
+        """
+        sgpro = SGProClass()
+        sgpro.DEVICE_TYPE = 'Camera'
+
+        self.changeStyleDynamic(self.ui.sgproDiscover, 'running', True)
+        deviceNames = sgpro.discoverDevices()
+        if not deviceNames:
+            self.message.emit('SGPro no devices found', 2)
+
+        deviceNames.insert(0, 'SGPro controlled')
+        self.changeStyleDynamic(self.ui.sgproDiscover, 'running', False)
+
+        for deviceName in deviceNames:
+            self.message.emit(f'SGPro discovered:    [{deviceName}]', 0)
+
+        self.updateSGProDeviceNameList(deviceNames=deviceNames)
+        return True
+
+    def updateNINADeviceNameList(self, deviceNames=[]):
+        """
+        updateSGProDeviceNameList updates the indi device name selectors
+        combobox with the discovered entries. therefore it deletes the old list
+        and rebuild it new.
+
+        :return: True for test purpose
+        """
+        self.ui.ninaDeviceList.clear()
+        self.ui.ninaDeviceList.setView(QListView())
+        for deviceName in deviceNames:
+            self.ui.ninaDeviceList.addItem(deviceName)
+        return True
+
+    def discoverNINADevices(self):
+        """
+        discoverSGProDevices looks all possible alpaca devices up from the
+        actual server and the selected device type.
+
+        :return: success
+        """
+        nina = NINAClass()
+        nina.DEVICE_TYPE = 'Camera'
+
+        self.changeStyleDynamic(self.ui.ninaDiscover, 'running', True)
+        deviceNames = nina.discoverDevices()
+        if not deviceNames:
+            self.message.emit('N.I.N.A. no devices found', 2)
+
+        deviceNames.insert(0, 'N.I.N.A. controlled')
+        self.changeStyleDynamic(self.ui.ninaDiscover, 'running', False)
+
+        for deviceName in deviceNames:
+            self.message.emit(f'N.I.N.A. discovered:[{deviceName}]', 0)
+
+        self.updateNINADeviceNameList(deviceNames=deviceNames)
+        return True
+
     def checkAstrometryAvailability(self, framework):
         """
         checkAvailability looks the presence of the binaries and indexes up and
