@@ -10,13 +10,12 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
 ###########################################################
 # standard libraries
-from base.packageConfig import isAvailable
 import os
 
 # external packages
@@ -32,13 +31,11 @@ from astropy.visualization import AsinhStretch
 from astropy.visualization import imshow_norm
 from matplotlib.patches import Ellipse
 import matplotlib.pyplot as plt
-if isAvailable:
-    from colour_demosaicing import demosaicing_CFA_Bayer_bilinear
 import sep
+from PIL import Image
 
 # local import
 from mountcontrol.convert import convertToDMS, convertToHMS
-from mountcontrol.convert import formatHstrToText, formatDstrToText
 from base.fitsHeader import getCoordinates, getSQM, getExposure, getScale
 from gui.utilities import toolsQtWidget
 from gui.widgets import image_ui
@@ -152,7 +149,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.ui.color.setCurrentIndex(config.get('color', 0))
         self.ui.zoom.setCurrentIndex(config.get('zoom', 0))
         self.ui.view.setCurrentIndex(config.get('view', 0))
-
         self.ui.stretch.setCurrentIndex(config.get('stretch', 0))
         self.imageFileName = config.get('imageFileName', '')
         self.folder = self.app.mwGlob.get('imageDir', '')
@@ -199,7 +195,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.ui.stretch.currentIndexChanged.connect(self.preparePlot)
         self.ui.zoom.currentIndexChanged.connect(self.showCurrent)
         self.ui.view.currentIndexChanged.connect(self.preparePlot)
-        self.ui.checkUseWCS.clicked.connect(self.preparePlot)
         self.ui.checkShowGrid.clicked.connect(self.preparePlot)
         self.ui.checkShowCrosshair.clicked.connect(self.preparePlot)
         self.ui.solve.clicked.connect(self.solveCurrent)
@@ -231,7 +226,6 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.ui.stretch.currentIndexChanged.disconnect(self.preparePlot)
         self.ui.zoom.currentIndexChanged.disconnect(self.showCurrent)
         self.ui.view.currentIndexChanged.disconnect(self.preparePlot)
-        self.ui.checkUseWCS.clicked.disconnect(self.preparePlot)
         self.ui.checkShowGrid.clicked.disconnect(self.preparePlot)
         self.ui.checkShowCrosshair.clicked.disconnect(self.preparePlot)
         self.ui.solve.clicked.disconnect(self.solveCurrent)
@@ -311,17 +305,17 @@ class ImageWindow(toolsQtWidget.MWidget):
             self.ui.solve.setEnabled(False)
 
         if self.deviceStat.get('expose', False):
-            self.changeStyleDynamic(self.ui.expose, 'running', 'true')
+            self.changeStyleDynamic(self.ui.expose, 'running', True)
         elif self.deviceStat.get('exposeN', False):
-            self.changeStyleDynamic(self.ui.exposeN, 'running', 'true')
+            self.changeStyleDynamic(self.ui.exposeN, 'running', True)
         else:
-            self.changeStyleDynamic(self.ui.expose, 'running', 'false')
-            self.changeStyleDynamic(self.ui.exposeN, 'running', 'false')
+            self.changeStyleDynamic(self.ui.expose, 'running', False)
+            self.changeStyleDynamic(self.ui.exposeN, 'running', False)
 
         if self.deviceStat.get('solve', False):
-            self.changeStyleDynamic(self.ui.solve, 'running', 'true')
+            self.changeStyleDynamic(self.ui.solve, 'running', True)
         else:
-            self.changeStyleDynamic(self.ui.solve, 'running', 'false')
+            self.changeStyleDynamic(self.ui.solve, 'running', False)
 
         return True
 
@@ -333,58 +327,18 @@ class ImageWindow(toolsQtWidget.MWidget):
                             'FITS files (*.fit*)', enableDir=True)
         loadFilePath, name, ext = val
         if not name:
+            self.app.message.emit('No image selected', 0)
             return False
 
         self.ui.imageFileName.setText(name)
         self.imageFileName = loadFilePath
-        self.app.message.emit(f'Image [{name}] selected', 0)
+        self.app.message.emit(f'Image selected:      [{name}]', 0)
         self.folder = os.path.dirname(loadFilePath)
+        if self.ui.checkAutoSolve.isChecked():
+            self.signals.solveImage.emit(self.imageFileName)
         self.app.showImage.emit(self.imageFileName)
         return True
 
-    def setupDistorted(self):
-        """
-        setupDistorted tries to setup all necessary context for displaying the
-        image with wcs distorted coordinates.
-
-        :return: true for test purpose
-        """
-        self.fig.clf()
-        self.axe = self.fig.add_subplot(1, 1, 1,
-                                        projection=wcs.WCS(self.header, relax=True),
-                                        facecolor=self.M_BACK)
-
-        self.fig.subplots_adjust(bottom=0.1, top=0.9, left=0.1, right=0.85)
-        self.axeCB = None
-        self.axe.coords.frame.set_color(self.M_BLUE)
-
-        axe0 = self.axe.coords[0]
-        axe1 = self.axe.coords[1]
-
-        if self.ui.checkShowGrid.isChecked():
-            axe0.grid(True, color=self.M_BLUE, ls='solid', alpha=0.5)
-            axe1.grid(True, color=self.M_BLUE, ls='solid', alpha=0.5)
-
-        axe0.tick_params(colors=self.M_BLUE, labelsize=12)
-        axe1.tick_params(colors=self.M_BLUE, labelsize=12)
-        axe0.set_axislabel('Right Ascension',
-                           color=self.M_BLUE,
-                           fontsize=12,
-                           fontweight='bold')
-        axe1.set_axislabel('Declination',
-                           color=self.M_BLUE,
-                           fontsize=12,
-                           fontweight='bold')
-        axe0.set_ticks(number=10)
-        axe1.set_ticks(number=10)
-        axe0.set_ticks_position('lr')
-        axe0.set_ticklabel_position('lr')
-        axe0.set_axislabel_position('lr')
-        axe1.set_ticks_position('tb')
-        axe1.set_ticklabel_position('tb')
-        axe1.set_axislabel_position('tb')
-        return True
-
     def setupNormal(self):
         """
         :return: True for test purpose
@@ -458,25 +412,26 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.stretch = AsinhStretch(a=value)
         return True
 
+    def imageRawPlot(self, imageDisp=None):
+        """
+        :return:
+        """
+        img = imshow_norm(imageDisp,
+                          ax=self.axe,
+                          origin='lower',
+                          interval=MinMaxInterval(),
+                          stretch=self.stretch,
+                          cmap=self.colorMap,
+                          aspect='auto')
+        return img
+
     def imagePlot(self):
         """
         :return:
         """
-        if self.objs is not None:
-            imageDisp = self.image - self.bk_back
-
-        else:
-            imageDisp = self.image
-
-        if self.ui.view.currentIndex() in [0, 1, 2, 3]:
-            imageDisp[imageDisp < 0] = 0
-            img = imshow_norm(imageDisp,
-                              ax=self.axe,
-                              origin='lower',
-                              interval=MinMaxInterval(),
-                              stretch=self.stretch,
-                              cmap=self.colorMap,
-                              aspect='auto')
+        if self.ui.view.currentIndex() == 0:
+            img = self.imageRawPlot(imageDisp=self.image)
+            self.log.debug('Show 0')
 
             if self.axeCB:
                 colorbar = self.fig.colorbar(img[0], cax=self.axeCB)
@@ -486,7 +441,12 @@ class ImageWindow(toolsQtWidget.MWidget):
                 yTicks = plt.getp(colorbar.ax.axes, 'yticklabels')
                 plt.setp(yTicks, color=self.M_BLUE, fontweight='bold')
 
-        if self.ui.view.currentIndex() == 1 and self.objs is not None:
+        if self.ui.view.currentIndex() == 1:
+            if self.objs is None:
+                self.log.debug('Show 1, no SEP data')
+                return False
+
+            self.imageRawPlot(imageDisp=self.image)
             for i in range(len(self.objs)):
                 e = Ellipse(xy=(self.objs['x'][i], self.objs['y'][i]),
                             width=6 * self.objs['a'][i],
@@ -496,7 +456,15 @@ class ImageWindow(toolsQtWidget.MWidget):
                 e.set_edgecolor(self.M_BLUE)
                 self.axe.add_artist(e)
 
-        if self.ui.view.currentIndex() == 2 and self.radius is not None:
+            if self.axeCB:
+                self.axeCB.axis('off')
+
+        if self.ui.view.currentIndex() == 2:
+            if self.objs is None or self.radius is None:
+                self.log.debug('Show 2, no SEP radius data')
+                return False
+
+            self.imageRawPlot(imageDisp=self.image)
             draw = self.radius.argsort()[-50:][::-1]
             for i in draw:
                 e = Ellipse(xy=(self.objs['x'][i], self.objs['y'][i]),
@@ -512,8 +480,15 @@ class ImageWindow(toolsQtWidget.MWidget):
                                   xy=(posX, posY),
                                   color=self.M_BLUE,
                                   fontweight='bold')
+            if self.axeCB:
+                self.axeCB.axis('off')
 
-        if self.ui.view.currentIndex() == 3 and self.objs is not None:
+        if self.ui.view.currentIndex() == 3:
+            if self.objs is None:
+                self.log.debug('Show 3, no SEP data')
+                return False
+
+            self.imageRawPlot(imageDisp=self.image)
             a = self.objs['a']
             b = self.objs['b']
             eccentricity = np.sqrt(1 - b ** 2 / a ** 2)
@@ -527,14 +502,12 @@ class ImageWindow(toolsQtWidget.MWidget):
             yTicks = plt.getp(colorbar.ax.axes, 'yticklabels')
             plt.setp(yTicks, color=self.M_BLUE, fontweight='bold')
 
-        if self.ui.view.currentIndex() == 4 and self.bk_back is not None:
-            img = imshow_norm(self.bk_back,
-                              ax=self.axe,
-                              origin='lower',
-                              interval=MinMaxInterval(),
-                              stretch=self.stretch,
-                              cmap=self.colorMap,
-                              aspect='auto')
+        if self.ui.view.currentIndex() == 4:
+            if self.bk_back is None:
+                self.log.debug('Show 4, no SEP background data')
+                return False
+
+            img = self.imageRawPlot(imageDisp=self.bk_back)
             if self.axeCB:
                 colorbar = self.fig.colorbar(img[0], cax=self.axeCB)
                 colorbar.set_label('Background level [adu]',
@@ -543,14 +516,12 @@ class ImageWindow(toolsQtWidget.MWidget):
                 yTicks = plt.getp(colorbar.ax.axes, 'yticklabels')
                 plt.setp(yTicks, color=self.M_BLUE, fontweight='bold')
 
-        if self.ui.view.currentIndex() == 5 and self.bk_rms is not None:
-            img = imshow_norm(self.bk_rms,
-                              ax=self.axe,
-                              origin='lower',
-                              interval=MinMaxInterval(),
-                              stretch=self.stretch,
-                              cmap=self.colorMap,
-                              aspect='auto')
+        if self.ui.view.currentIndex() == 5:
+            if self.bk_rms is None:
+                self.log.debug('Show 5, no SEP background rms data')
+                return False
+
+            img = self.imageRawPlot(imageDisp=self.bk_rms)
             if self.axeCB:
                 colorbar = self.fig.colorbar(img[0], cax=self.axeCB)
                 colorbar.set_label('Background noise [adu]',
@@ -560,7 +531,11 @@ class ImageWindow(toolsQtWidget.MWidget):
                 plt.setp(yTicks, color=self.M_BLUE,
                          fontweight='bold')
 
-        if self.ui.view.currentIndex() == 6 and self.flux is not None:
+        if self.ui.view.currentIndex() == 6:
+            if self.flux is None or self.objs is None:
+                self.log.debug('Show 5, no SEP flux data')
+                return False
+
             flux = np.log(self.flux)
             area = 3 * flux
             scatter = self.axe.scatter(self.objs['x'], self.objs['y'],
@@ -571,20 +546,21 @@ class ImageWindow(toolsQtWidget.MWidget):
             yTicks = plt.getp(colorbar.ax.axes, 'yticklabels')
             plt.setp(yTicks, color=self.M_BLUE, fontweight='bold')
 
-        if self.ui.view.currentIndex() == 7 and self.radius is not None and \
-                self.objs is not None:
+        if self.ui.view.currentIndex() == 7:
+            if self.radius is None or self.objs is None:
+                self.log.debug('Show 7, no SEP radius data')
+                return False
 
             x = self.objs['x']
             y = self.objs['y']
             z = self.radius
-            width = imageDisp.shape[1]
-            height = imageDisp.shape[0]
+            width = self.image.shape[1]
+            height = self.image.shape[0]
             X, Y = np.meshgrid(range(0, width, int(width / 250)),
                                range(0, height, int(height / 250)))
             Z = griddata((x, y), z, (X, Y), method='linear', fill_value=np.mean(z))
             Z = uniform_filter(Z, size=25)
             self.axe.contourf(X, Y, Z, 20)
-
             if self.axeCB:
                 self.axeCB.axis('off')
 
@@ -596,84 +572,47 @@ class ImageWindow(toolsQtWidget.MWidget):
         :param header:
         :return: True for test purpose
         """
-        name = header.get('OBJECT', '').upper()
-        self.ui.object.setText(f'{name}')
-
+        self.guiSetText(self.ui.object, 's', header.get('OBJECT', '').upper())
         ra, dec = getCoordinates(header=header)
-
-        self.ui.ra.setText(f'{formatHstrToText(ra)}')
-        self.ui.dec.setText(f'{formatDstrToText(dec)}')
-
-        scale = getScale(header=header)
-        rotation = header.get('ANGLE', 0)
-        self.ui.scale.setText(f'{scale:5.3f}')
-        self.ui.rotation.setText(f'{rotation:6.3f}')
-
-        value = header.get('CCD-TEMP', 0)
-        self.guiSetText(self.ui.ccdTemp, '4.1f', value)
-
-        value = getExposure(header=header)
-        self.guiSetText(self.ui.expTime, '5.1f', value)
-
-        value = header.get('FILTER', 0)
-        value = f'{value}'
-        self.guiSetText(self.ui.filter, 's', value)
-
-        value = header.get('XBINNING', 0)
-        self.guiSetText(self.ui.binX, '1.0f', value)
-        value = header.get('YBINNING', 0)
-        self.guiSetText(self.ui.binY, '1.0f', value)
-
-        value = getSQM(header=header)
-        self.guiSetText(self.ui.sqm, '5.2f', value)
-
+        self.guiSetText(self.ui.ra, 'HSTR', ra)
+        self.guiSetText(self.ui.dec, 'DSTR', dec)
+        self.guiSetText(self.ui.scale, '5.3f', getScale(header=header))
+        self.guiSetText(self.ui.rotation, '6.3f', header.get('ANGLE'))
+        self.guiSetText(self.ui.ccdTemp, '4.1f', header.get('CCD-TEMP'))
+        self.guiSetText(self.ui.expTime, '5.1f', getExposure(header=header))
+        self.guiSetText(self.ui.filter, 's', header.get('FILTER'))
+        self.guiSetText(self.ui.binX, '1.0f', header.get('XBINNING'))
+        self.guiSetText(self.ui.binY, '1.0f', header.get('YBINNING'))
+        self.guiSetText(self.ui.sqm, '5.2f', getSQM(header=header))
         flipped = bool(header.get('FLIPPED', False))
         self.ui.isFlipped.setEnabled(flipped)
-
         return True
 
-    def workerPreparePlot(self, header):
+    def workerPreparePlot(self):
         """
-        :param header:
         :return:
         """
         self.updateWindowsStats()
-        if 'CTYPE1' in header:
-            wcsObject = wcs.WCS(header, relax=True)
-            hasCelestial = wcsObject.has_celestial
-            hasDistortion = wcsObject.has_distortion
-
-        else:
-            hasCelestial = False
-            hasDistortion = False
-
-        self.ui.hasDistortion.setEnabled(hasDistortion)
-        self.ui.checkUseWCS.setEnabled(hasDistortion)
-        self.ui.hasWCS.setEnabled(hasCelestial)
-
-        canWCS = self.ui.view.currentIndex() in [0, 1, 2]
-        useWCS = self.ui.checkUseWCS.isChecked()
-
-        if hasDistortion and useWCS and canWCS:
-            self.setupDistorted()
-        else:
-            self.setupNormal()
-
-        self.writeHeaderDataToGUI(header)
+        self.setupNormal()
+        self.writeHeaderDataToGUI(self.header)
         self.stretchImage()
         self.colorImage()
-        self.imagePlot()
-        return True
+        suc = self.imagePlot()
+        if not suc:
+            t = 'Image type could not be shown - display raw image'
+            self.app.message.emit(t, 2)
+            self.ui.view.setCurrentIndex(0)
+        return suc
 
     def preparePlot(self):
         """
         :return:
         """
-        worker = Worker(self.workerPreparePlot, self.header)
+        worker = Worker(self.workerPreparePlot)
         self.threadPool.start(worker)
         return True
 
-    def workerPhotometry(self):
+    def workerPreparePhotometry(self):
         """
         :return:
         """
@@ -681,7 +620,9 @@ class ImageWindow(toolsQtWidget.MWidget):
         self.bk_back = bkg.back()
         self.bk_rms = bkg.rms()
         image_sub = self.image - bkg
-        self.objs = sep.extract(image_sub, 1.5, err=bkg.globalrms)
+        self.objs = sep.extract(image_sub, 1.5, err=bkg.globalrms,
+                                filter_type='conv',
+                                minarea=10)
         self.flux, _, _ = sep.sum_circle(image_sub,
                                          self.objs['x'],
                                          self.objs['y'],
@@ -697,17 +638,16 @@ class ImageWindow(toolsQtWidget.MWidget):
                                          subpix=5)
         return True
 
-    def prepareImageForPhotometry(self):
+    def preparePhotometry(self):
         """
         :return:
         """
-        if not self.objs:
-            worker = Worker(self.workerPhotometry)
+        if self.objs is None:
+            worker = Worker(self.workerPreparePhotometry)
             worker.signals.finished.connect(self.preparePlot)
             self.threadPool.start(worker)
         else:
             self.preparePlot()
-
         return True
 
     def stackImages(self):
@@ -757,6 +697,7 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         position = (int(sizeX / 2), int(sizeY / 2))
         size = (int(sizeY / factor), int(sizeX / factor))
+        self.log.debug(f'Image zoomed to position:[{position}], size:[{size}]')
         self.image = Cutout2D(self.image,
                               position=position,
                               size=size,
@@ -764,21 +705,77 @@ class ImageWindow(toolsQtWidget.MWidget):
                               copy=True).data
         return True
 
+    def debayerImage(self, image, pattern):
+        """
+        :param: image:
+        :param: pattern:
+        :return:
+        """
+        w = image.shape[0]
+        h = image.shape[1]
+        if pattern == 'GBRG':
+            R = image[1::2, 0::2]
+            B = image[0::2, 1::2]
+            G0 = image[0::2, 0::2]
+            G1 = image[1::2, 1::2]
+
+        elif pattern == 'RGGB':
+            R = image[0::2, 0::2]
+            B = image[1::2, 1::2]
+            G0 = image[0::2, 1::2]
+            G1 = image[1::2, 0::2]
+
+        elif pattern == 'GRBG':
+            R = image[0::2, 1::2]
+            B = image[1::2, 0::2]
+            G0 = image[0::2, 0::2]
+            G1 = image[1::2, 1::2]
+
+        elif pattern == 'BGGR':
+            R = image[1::2, 1::2]
+            B = image[0::2, 0::2]
+            G0 = image[0::2, 1::2]
+            G1 = image[1::2, 0::2]
+
+        else:
+            self.log.info('Unknown debayer pattern, keep it')
+            return image
+
+        image = 0.2989 * R + 0.5870 * (G0 + G1) / 2 + 0.1140 * B
+        image = np.array(Image.fromarray(image).resize((h, w)))
+        return image
+
+    def workerLoadImage(self):
+        """
+        :return:
+        """
+        full, short, ext = self.extractNames([self.imageFileName])
+        self.ui.imageFileName.setText(short)
+
+        with fits.open(self.imageFileName, mode='update') as fitsHandle:
+            self.image = fitsHandle[0].data
+            self.header = fitsHandle[0].header
+
+        if self.image is None or len(self.image) == 0:
+            self.log.debug('No image data in FITS')
+            return False
+        if self.header is None:
+            self.log.debug('No header data in FITS')
+            return False
+
+        self.image = np.flipud(self.image).astype('float32')
+        bayerPattern = self.header.get('BAYERPAT', '')
+        if bayerPattern:
+            self.image = self.debayerImage(self.image, bayerPattern)
+            self.log.debug(f'Image has bayer pattern: {bayerPattern}')
+
+        self.zoomImage()
+        self.stackImages()
+        self.objs = None
+        return True
+
     def showImage(self, imagePath=''):
         """
-        tho idea of processing the image data until it is shown on screen is
-        to split the pipeline in several atomic steps, which follow each other.
-        each step is calling the next one and depending which user interaction is
-        done and how the use case for changing the view is the entrance of the
-        pipeline is chosen adequately.
-
-        so we have step 1 loading data and processing if to final monochrome and
-        sized format
-        - loading data
-        - debayer if necessary
-        - getting header data and cleaning it up
-        - zoom and stack
-
         :param: imagePath:
         :return:
         """
@@ -787,37 +784,11 @@ class ImageWindow(toolsQtWidget.MWidget):
         if not os.path.isfile(imagePath):
             return False
 
+        self.ui.loading.setText('Loading....')
         self.imageFileName = imagePath
-        full, short, ext = self.extractNames([imagePath])
-        self.ui.imageFileName.setText(short)
-
-        with fits.open(imagePath, mode='update') as fitsHandle:
-            self.image = fitsHandle[0].data
-            self.header = fitsHandle[0].header
-
-        if self.image is None or len(self.image) == 0:
-            return False
-        if self.header is None:
-            return False
-
-        self.image = self.image.astype('float32')
-
-        if 'BAYERPAT' in self.header and isAvailable:
-            self.image = demosaicing_CFA_Bayer_bilinear(self.image)
-            self.image = np.dot(self.image, [0.2989, 0.5870, 0.1140])
-
-        # correct faulty headers, because some imaging programs did not
-        # interpret the Keywords in the right manner (SGPro)
-        if self.header.get('CTYPE1', '').endswith('DEF'):
-            self.header['CTYPE1'] = self.header['CTYPE1'].replace('DEF', 'TAN')
-
-        if self.header.get('CTYPE2', '').endswith('DEF'):
-            self.header['CTYPE2'] = self.header['CTYPE2'].replace('DEF', 'TAN')
-
-        self.zoomImage()
-        self.stackImages()
-        self.objs = None
-        self.prepareImageForPhotometry()
+        worker = Worker(self.workerLoadImage)
+        worker.signals.finished.connect(self.preparePhotometry)
+        self.threadPool.start(worker)
         return True
 
     def showCurrent(self):
@@ -849,6 +820,7 @@ class ImageWindow(toolsQtWidget.MWidget):
                                      )
         if not suc:
             text = f'Cannot expose:       [{os.path.basename(imagePath)}]'
+            self.abortImage()
             self.app.message.emit(text, 2)
             return False
 
@@ -871,9 +843,7 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         if self.ui.checkAutoSolve.isChecked():
             self.signals.solveImage.emit(imagePath)
-        else:
-            self.app.showImage.emit(imagePath)
-
+        self.app.showImage.emit(imagePath)
         return True
 
     def exposeImage(self):
@@ -881,7 +851,7 @@ class ImageWindow(toolsQtWidget.MWidget):
         :return: success
         """
         self.expTime = self.app.camera.expTime
-        self.binning = self.app.camera.binning
+        self.binning = int(self.app.camera.binning)
         self.imageStack = None
         self.deviceStat['expose'] = True
         self.ui.checkStackImages.setChecked(False)
@@ -900,9 +870,7 @@ class ImageWindow(toolsQtWidget.MWidget):
 
         if self.ui.checkAutoSolve.isChecked():
             self.signals.solveImage.emit(imagePath)
-        else:
-            self.app.showImage.emit(imagePath)
-
+        self.app.showImage.emit(imagePath)
         self.exposeRaw()
         return True
 
@@ -911,7 +879,7 @@ class ImageWindow(toolsQtWidget.MWidget):
         :return: success
         """
         self.expTime = self.app.camera.expTimeN
-        self.binning = self.app.camera.binningN
+        self.binning = int(self.app.camera.binningN)
         self.imageStack = None
         self.deviceStat['exposeN'] = True
         self.app.camera.signals.saved.connect(self.exposeImageNDone)
@@ -969,11 +937,6 @@ class ImageWindow(toolsQtWidget.MWidget):
             self.app.message.emit(text, 2)
             return False
 
-        isStack = self.ui.checkStackImages.isChecked()
-        isAutoSolve = self.ui.checkAutoSolve.isChecked()
-
-        if not isStack or isAutoSolve:
-            self.app.showImage.emit(result['solvedPath'])
         return True
 
     def solveImage(self, imagePath=''):
