@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -99,6 +99,107 @@ class SettImaging(object):
         config['checkAutomaticTelescope'] = self.ui.checkAutomaticTelescope.isChecked()
         return True
 
+    def checkEnableCameraUI(self):
+        """
+        :return:
+        """
+        coolerTemp = self.app.camera.data.get('CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE')
+        coolerPower = self.app.camera.data.get('CCD_COOLER_POWER.CCD_COOLER_VALUE')
+        gainCam = self.app.camera.data.get('CCD_GAIN.GAIN')
+        offsetCam = self.app.camera.data.get('CCD_OFFSET.OFFSET')
+        humidityCCD = self.app.camera.data.get('CCD_HUMIDITY.HUMIDITY')
+        coolerOn = self.app.camera.data.get('CCD_COOLER.COOLER_ON')
+        downloadFast = self.app.camera.data.get('READOUT_QUALITY.QUALITY_LOW')
+        pixelSizeX = self.app.camera.data.get('CCD_INFO.CCD_PIXEL_SIZE_X')
+        pixelSizeY = self.app.camera.data.get('CCD_INFO.CCD_PIXEL_SIZE_Y')
+        pixelX = self.app.camera.data.get('CCD_INFO.CCD_MAX_X')
+        pixelY = self.app.camera.data.get('CCD_INFO.CCD_MAX_Y')
+
+        enable = coolerTemp is not None
+        self.ui.coolerTemp.setEnabled(enable)
+        enable = coolerPower is not None
+        self.ui.coolerPower.setEnabled(enable)
+        enable = gainCam is not None
+        self.ui.gainCam.setEnabled(enable)
+        enable = offsetCam is not None
+        self.ui.offsetCam.setEnabled(enable)
+        enable = humidityCCD is not None
+        self.ui.humidityCCD.setEnabled(enable)
+        enable = coolerOn is not None
+        self.ui.coolerOn.setEnabled(enable)
+        self.ui.coolerOff.setEnabled(enable)
+        enable = downloadFast is not None
+        self.ui.downloadFast.setEnabled(enable)
+        self.ui.downloadSlow.setEnabled(enable)
+        enable = pixelSizeX is not None
+        self.ui.pixelSizeX.setEnabled(enable)
+        enable = pixelSizeY is not None
+        self.ui.pixelSizeY.setEnabled(enable)
+        enable = pixelX is not None
+        self.ui.pixelX.setEnabled(enable)
+        enable = pixelY is not None
+        self.ui.pixelY.setEnabled(enable)
+        self.ui.subFrame.setEnabled(enable)
+        return True
+
+    def updateGainOffset(self):
+        """
+        :return:
+        """
+        actValue = self.app.camera.data.get('CCD_OFFSET.OFFSET')
+        offsetList = self.app.camera.data.get('CCD_OFFSET.OFFSET_LIST')
+        if offsetList is not None and actValue is not None:
+            offsetList = list(offsetList)
+            self.guiSetText(self.ui.offsetCam, 's', offsetList[actValue])
+        else:
+            self.guiSetText(self.ui.offsetCam, '3.0f', actValue)
+
+        actValue = self.app.camera.data.get('CCD_GAIN.GAIN')
+        gainList = self.app.camera.data.get('CCD_GAIN.GAIN_LIST')
+        if gainList is not None and actValue is not None:
+            gainList = list(gainList)
+            self.guiSetText(self.ui.gainCam, 's', gainList[actValue])
+        else:
+            self.guiSetText(self.ui.gainCam, '3.0f', actValue)
+
+        return True
+
+    def updateCooler(self):
+        """
+        :return:
+        """
+        coolerTemp = self.app.camera.data.get('CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE', 0)
+        coolerPower = self.app.camera.data.get('CCD_COOLER_POWER.CCD_COOLER_VALUE', 0)
+        coolerOn = self.app.camera.data.get('CCD_COOLER.COOLER_ON', False)
+        self.guiSetText(self.ui.coolerTemp, '3.1f', coolerTemp)
+        self.guiSetText(self.ui.coolerPower, '3.1f', coolerPower)
+        if coolerOn:
+            self.changeStyleDynamic(self.ui.coolerOn, 'running', True)
+            self.changeStyleDynamic(self.ui.coolerOff, 'running', False)
+        else:
+            self.changeStyleDynamic(self.ui.coolerOn, 'running', False)
+            self.changeStyleDynamic(self.ui.coolerOff, 'running', True)
+        return True
+
+    def updateFilter(self):
+        """
+        :return:
+        """
+        filterNumber = self.app.filter.data.get('FILTER_SLOT.FILTER_SLOT_VALUE', 1)
+        key = f'FILTER_NAME.FILTER_SLOT_NAME_{filterNumber:1.0f}'
+        filterName = self.app.filter.data.get(key, 'not found')
+        self.guiSetText(self.ui.filterNumber, '1.0f', filterNumber)
+        self.guiSetText(self.ui.filterName, 's', filterName)
+        return True
+
+    def updateFocuser(self):
+        """
+        :return:
+        """
+        focus = self.app.focuser.data.get('ABS_FOCUS_POSITION.FOCUS_ABSOLUTE_POSITION', 0)
+        self.guiSetText(self.ui.focuserPosition, '6.0f', focus)
+        return True
+
     def updateParameters(self):
         """
         updateParameters reads the data from the classes and writes them to the gui.
@@ -106,9 +207,15 @@ class SettImaging(object):
 
         :return: true for test purpose
         """
+        self.checkEnableCameraUI()
         if self.ui.checkAutomaticTelescope.isChecked():
             self.updateTelescopeParametersToGui()
 
+        self.updateGainOffset()
+        self.updateCooler()
+        self.updateFilter()
+        self.updateFocuser()
+
         focalLength = self.ui.focalLength.value()
         aperture = self.ui.aperture.value()
         pixelSizeX = self.app.camera.data.get('CCD_INFO.CCD_PIXEL_SIZE_X', 0)
@@ -118,15 +225,8 @@ class SettImaging(object):
         maxBinX = self.app.camera.data.get('CCD_BINNING.HOR_BIN_MAX', 9)
         maxBinY = self.app.camera.data.get('CCD_BINNING.HOR_BIN_MAX', 9)
         rotation = self.app.camera.data.get('CCD_ROTATION.CCD_ROTATION_VALUE', 0)
-        coolerTemp = self.app.camera.data.get('CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE', 0)
-        coolerPower = self.app.camera.data.get('CCD_COOLER_POWER.CCD_COOLER_VALUE', 0)
-        gainCam = self.app.camera.data.get('CCD_GAIN.GAIN')
-        offsetCam = self.app.camera.data.get('CCD_OFFSET.OFFSET')
         humidityCCD = self.app.camera.data.get('CCD_HUMIDITY.HUMIDITY')
-        coolerOn = self.app.camera.data.get('CCD_COOLER.COOLER_ON', False)
         downloadFast = self.app.camera.data.get('READOUT_QUALITY.QUALITY_LOW', False)
-        focus = self.app.focuser.data.get('ABS_FOCUS_POSITION.FOCUS_ABSOLUTE_POSITION', 0)
-        filterNumber = self.app.filter.data.get('FILTER_SLOT.FILTER_SLOT_VALUE', 1)
 
         if maxBinX and maxBinY:
             maxBin = min(maxBinX, maxBinY)
@@ -142,9 +242,6 @@ class SettImaging(object):
         self.app.telescope.focalLength = focalLength
         self.app.telescope.aperture = aperture
 
-        key = f'FILTER_NAME.FILTER_SLOT_NAME_{filterNumber:1.0f}'
-        filterName = self.app.filter.data.get(key, 'not found')
-
         if focalLength and pixelSizeX and pixelSizeY:
             resolutionX = pixelSizeX / focalLength * 206.265
             resolutionY = pixelSizeY / focalLength * 206.265
@@ -173,8 +270,6 @@ class SettImaging(object):
             FOVX = None
             FOVY = None
 
-        self.guiSetText(self.ui.filterNumber, '1.0f', filterNumber)
-        self.guiSetText(self.ui.filterName, 's', filterName)
         self.guiSetText(self.ui.speed, '2.1f', speed)
         self.guiSetText(self.ui.pixelSizeX, '2.2f', pixelSizeX)
         self.guiSetText(self.ui.pixelSizeY, '2.2f', pixelSizeY)
@@ -182,11 +277,6 @@ class SettImaging(object):
         self.guiSetText(self.ui.pixelY, '5.0f', pixelY)
         self.guiSetText(self.ui.rotation, '3.1f', rotation)
         self.guiSetText(self.ui.humidityCCD, '3.1f', humidityCCD)
-        self.guiSetText(self.ui.coolerTemp, '3.1f', coolerTemp)
-        self.guiSetText(self.ui.coolerPower, '3.1f', coolerPower)
-        self.guiSetText(self.ui.gainCam, '3.0f', gainCam)
-        self.guiSetText(self.ui.offsetCam, '3.0f', offsetCam)
-        self.guiSetText(self.ui.focuserPosition, '6.0f', focus)
         self.guiSetText(self.ui.resolutionX, '2.2f', resolutionX)
         self.guiSetText(self.ui.resolutionY, '2.2f', resolutionY)
         self.guiSetText(self.ui.dawes, '2.2f', dawes)
@@ -195,13 +285,6 @@ class SettImaging(object):
         self.guiSetText(self.ui.FOVX, '2.2f', FOVX)
         self.guiSetText(self.ui.FOVY, '2.2f', FOVY)
 
-        if coolerOn:
-            self.changeStyleDynamic(self.ui.coolerOn, 'running', True)
-            self.changeStyleDynamic(self.ui.coolerOff, 'running', False)
-        else:
-            self.changeStyleDynamic(self.ui.coolerOn, 'running', False)
-            self.changeStyleDynamic(self.ui.coolerOff, 'running', True)
-
         if downloadFast:
             self.changeStyleDynamic(self.ui.downloadFast, 'running', True)
             self.changeStyleDynamic(self.ui.downloadSlow, 'running', False)
@@ -238,23 +321,16 @@ class SettImaging(object):
         if not canSetCCDTemp:
             return False
 
-        msg = PyQt5.QtWidgets.QMessageBox
         actValue = self.app.camera.data.get(
             'CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE', None)
         if actValue is None:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when not connected !')
             return False
+
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getInt(self,
                                'Set cooler temperature',
-                               'Value (-20..+20):',
-                               actValue,
-                               -20,
-                               20,
-                               1,
-                               )
+                               'Value (-30..+20):',
+                               actValue, -30, 20, 1)
         if not ok:
             return False
 
@@ -265,22 +341,35 @@ class SettImaging(object):
         """
         :return: success
         """
-        msg = PyQt5.QtWidgets.QMessageBox
         actValue = self.app.camera.data.get('CCD_OFFSET.OFFSET', None)
         if actValue is None:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when not connected !')
             return False
+
         dlg = PyQt5.QtWidgets.QInputDialog()
-        value, ok = dlg.getInt(self,
-                               'Set offset',
-                               'Value (0..255):',
-                               actValue,
-                               0,
-                               255,
-                               1,
-                               )
+        offsetList = self.app.camera.data.get('CCD_OFFSET.OFFSET_LIST')
+        offsetMin = self.app.camera.data.get('CCD_OFFSET.OFFSET_MIN')
+        offsetMax = self.app.camera.data.get('CCD_OFFSET.OFFSET_MAX')
+        if offsetList is not None:
+            offsetList = list(offsetList)
+            value, ok = dlg.getItem(self,
+                                    'Set offset', 'Offset entry: ',
+                                    offsetList, actValue)
+            value = offsetList.index(value)
+
+        elif offsetMin is not None and offsetMax is not None:
+            offsetMin = int(offsetMin)
+            offsetMax = int(offsetMax)
+            value, ok = dlg.getInt(self,
+                                   'Set offset',
+                                   f'Values ({offsetMin:4}..{offsetMax:4}):',
+                                   actValue, offsetMin, offsetMax,
+                                   int((offsetMax - offsetMin) / 20))
+        else:
+            value, ok = dlg.getInt(self,
+                                   'Set offset',
+                                   'Values:',
+                                   actValue)
+
         if not ok:
             return False
 
@@ -291,24 +380,35 @@ class SettImaging(object):
         """
         :return: success
         """
-        msg = PyQt5.QtWidgets.QMessageBox
-        minGain = self.app.camera.data.get('CCD_INFO.GAIN_MIN', 1)
-        maxGain = self.app.camera.data.get('CCD_INFO.GAIN_MAX', 200)
         actValue = self.app.camera.data.get('CCD_GAIN.GAIN', None)
         if actValue is None:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when not connected !')
             return False
+
         dlg = PyQt5.QtWidgets.QInputDialog()
-        value, ok = dlg.getInt(self,
-                               'Set gain',
-                               'Value (0..255):',
-                               actValue,
-                               minGain,
-                               maxGain,
-                               1,
-                               )
+        gainList = self.app.camera.data.get('CCD_GAIN.GAIN_LIST')
+        gainMin = self.app.camera.data.get('CCD_GAIN.GAIN_MIN')
+        gainMax = self.app.camera.data.get('CCD_GAIN.GAIN_MAX')
+        if gainList is not None:
+            gainList = list(gainList)
+            value, ok = dlg.getItem(self,
+                                    'Set gain', 'Gain entry: ',
+                                    gainList, actValue)
+            value = gainList.index(value)
+
+        elif gainMin is not None and gainMax is not None:
+            gainMin = int(gainMin)
+            gainMax = int(gainMax)
+            value, ok = dlg.getInt(self,
+                                   'Set offset',
+                                   f'Values ({gainMin:4}..{gainMax:4}):',
+                                   actValue, gainMin, gainMax,
+                                   int((gainMax - gainMin) / 20))
+        else:
+            value, ok = dlg.getInt(self,
+                                   'Set offset',
+                                   'Values:',
+                                   actValue)
+
         if not ok:
             return False
 
@@ -319,14 +419,9 @@ class SettImaging(object):
         """
         :return: success
         """
-        msg = PyQt5.QtWidgets.QMessageBox
         data = self.app.filter.data
-
         actValue = data.get('FILTER_SLOT.FILTER_SLOT_VALUE')
         if actValue is None:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when not connected !')
             return False
 
         availNames = list(data[key] for key in data if 'FILTER_NAME.FILTER_SLOT_NAME_' in key)
@@ -359,14 +454,9 @@ class SettImaging(object):
         """
         :return: success
         """
-        msg = PyQt5.QtWidgets.QMessageBox
         data = self.app.filter.data
-
         actValue = data.get('FILTER_SLOT.FILTER_SLOT_VALUE')
         if actValue is None:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when not connected !')
             return False
 
         availNames = list(data[key] for key in data if 'FILTER_NAME.FILTER_SLOT_NAME_' in key)
@@ -540,14 +630,11 @@ class SettImaging(object):
         """
         :return: success
         """
-        msg = PyQt5.QtWidgets.QMessageBox
         actValue = self.app.cover.data.get(
             'FLAT_LIGHT_INTENSITY.FLAT_LIGHT_INTENSITY_VALUE')
         if actValue is None:
-            msg.critical(self,
-                         'Error Message',
-                         'Value cannot be set when not connected !')
             return False
+
         dlg = PyQt5.QtWidgets.QInputDialog()
         value, ok = dlg.getInt(self,
                                'Set light intensity',
