@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -49,7 +49,7 @@ class SplashScreen(QObject):
         self._qapp = application
         self.x = x
         self.y = y
-        self._pxm = QPixmap(':/icon/mw4.ico')
+        self._pxm = QPixmap(':/icon/mw4.png')
 
         flags = (Qt.WindowStaysOnTopHint | Qt.X11BypassWindowManagerHint)
         self.qss = QSplashScreen(self._pxm, flags)
