@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -145,9 +145,6 @@ class Styles:
             color: $M_BLUE$;
             background-color: $M_BACK$;
         }
-        QLineEdit::item:active {
-            border-color: $M_BLUE$;
-        }
         QTextEdit {
             color: $M_WHITE$;
             background-color: $M_BLACK$;
@@ -197,6 +194,13 @@ class Styles:
             border-style: flat;
             border-radius: 2px;
         }
+        QLineEdit::item:active {
+            border-color: $M_BLUE$;
+        }
+        QLineEdit:disabled {
+            background-color: $M_GREY1$;
+            color: $M_BLUE$;
+        }
         QLineEdit[keypad] {
             background-color: $M_BACK$;
             color: $M_BLUE$;
@@ -298,6 +302,13 @@ class Styles:
         QGroupBox::title:disabled{
             color: $M_BLUE1$;
         }
+        QGroupBox[frameless='true'] {
+            border-width: 0px;
+        }
+        QGroupBox[frameless='true']:disabled {
+            border-width: 2px;
+            border-color: $M_RED$;
+        }
         QGroupBox::indicator {
             border-width: 1px;
             border-color: $M_GREY$;
