@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -18,13 +18,15 @@
 # standard libraries
 import os
 import logging
+import datetime
 
 # external packages
 from PyQt5.QtWidgets import QWidget, QDesktopWidget, QFileDialog, QMessageBox
-from PyQt5.QtWidgets import QTableWidgetItem
+from PyQt5.QtWidgets import QTableWidgetItem, QPushButton
 from PyQt5.QtGui import QPalette, QIcon, QPixmap, QColor, QPainter, QImage
 from PyQt5.QtCore import QSortFilterProxyModel, QDir, QObject, pyqtSignal
 from PyQt5.QtCore import Qt, QSize, QEvent
+from PyQt5.QtTest import QTest
 import numpy as np
 from qimage2ndarray import rgb_view, array2qimage
 
@@ -37,9 +39,19 @@ __all__ = [
     'MWidget',
     'FileSortProxyModel',
     'QMultiWait',
+    'sleepAndEvents',
 ]
 
 
+def sleepAndEvents(value):
+    """
+    :param value: wait time in msec
+    :return:
+    """
+    QTest.qWait(value)
+    return True
+
+
 class FileSortProxyModel(QSortFilterProxyModel):
     """
     FileSortProxyModel enables a proxy solution for reversing the order of all
@@ -164,17 +176,55 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
 
             if not indexValue:
                 continue
-
             if relaxed:
                 if searchString in indexValue:
                     return index
-
             else:
                 if indexValue.startswith(searchString):
                     return index
-
         return 0
 
+    def saveWindowAsPNG(self, window):
+        """
+        :param window:
+        :return:
+        """
+        name = window.windowTitle().replace(' ', '_')
+        timeTrigger = datetime.datetime.now(datetime.timezone.utc)
+        timeTag = timeTrigger.strftime('%Y-%m-%d-%H-%M-%S')
+        path = self.app.mwGlob['workDir']
+        fullFileName = f'{path}/{timeTag}-{name}.png'
+        self.log.info(f'Screenshot: [{fullFileName}]')
+        window.grab().save(fullFileName)
+        return True
+
+    def saveAllWindowsAsPNG(self):
+        """
+        :return:
+        """
+        windows = self.app.uiWindows
+        self.saveWindowAsPNG(self.app.mainW)
+        for window in windows:
+            obj = windows[window]['classObj']
+            if obj:
+                self.saveWindowAsPNG(obj)
+        return True
+
+    def keyPressEvent(self, keyEvent):
+        """
+        Pressing F5 makes a screen copy of the actual window
+        Pressing F6 makes a screen copy of all open windows
+        :param keyEvent:
+        :return:
+        """
+        if keyEvent.key() == 16777268:
+            self.saveWindowAsPNG(self)
+            return
+        elif keyEvent.key() == 16777269:
+            self.saveAllWindowsAsPNG()
+            return
+        super().keyPressEvent(keyEvent)
+
     def img2pixmap(self, img, detect=None, color=None):
         """
         :param img:
@@ -237,6 +287,21 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         gui.style().polish(gui)
         return True
 
+    @staticmethod
+    def changeIconColor(widget, color):
+        """
+        :param widget:
+        :param color:
+        :return:
+        """
+        icon = widget.icon()
+        pixmap = icon.pixmap(icon.actualSize(QSize(64, 64)))
+        mask = pixmap.createMaskFromColor(QColor('transparent'), Qt.MaskInColor)
+        pixmap.fill(QColor(color))
+        pixmap.setMask(mask)
+        widget.setIcon(QIcon(pixmap))
+        return True
+
     def initUI(self):
         """
         init_UI makes the basic initialisation of the GUI. is sets the window
@@ -251,8 +316,7 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         self.setWindowIcon(QIcon(':/mw4.ico'))
         return True
 
-    @staticmethod
-    def changeStyleDynamic(widget=None, widgetProperty=None, value=None):
+    def changeStyleDynamic(self, widget=None, widgetProperty=None, value=None):
         """
         changeStyleDynamic changes the stylesheet of a given ui element and
         makes it visible. therefore the element has to be unpolished and
@@ -274,6 +338,12 @@ class MWidget(QWidget, Styles, ToolsMatplotlib):
         if widget.property(widgetProperty) == value:
             return True
 
+        if isinstance(widget, QPushButton):
+            if widgetProperty == 'running' and value:
+                self.changeIconColor(widget, self.M_BACK)
+            elif widgetProperty == 'running' and not value:
+                self.changeIconColor(widget, self.M_BLUE)
+
         widget.style().unpolish(widget)
         widget.setProperty(widgetProperty, value)
         widget.style().polish(widget)
