@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 # Licence APL2.0
 #
 ###########################################################
@@ -364,8 +364,8 @@ def convertRaToAngle(value):
         return None
 
     value = value.strip()
-    p1 = re.compile(r'([+-]?)(\d{1,3})H\s*(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
-    p2 = re.compile(r'([+-]?)(\d{1,3})\s+(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
+    p1 = re.compile(r'([+-]?)(\d{1,3})H[\s:]*(\d\d)?[\s:]*(\d\d)?[.,]?(\d*)?')
+    p2 = re.compile(r'([+-]?)(\d{1,3})[\s:]+(\d\d)?[\s:]*(\d\d)?[.,]?(\d*)?')
     p3 = re.compile(r'([+-]?)(\d{1,3})[.,]?(\d*)?')
     isP1 = p1.fullmatch(value) is not None
     isP2 = p2.fullmatch(value) is not None
@@ -411,8 +411,8 @@ def convertDecToAngle(value):
         return None
 
     value = value.strip()
-    p1 = re.compile(r'([+-]?)(\d{1,3})Deg\s*(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
-    p2 = re.compile(r'([+-]?)(\d{1,3})\s+(\d\d)?\s*(\d\d)?[.,]?(\d*)?')
+    p1 = re.compile(r'([+-]?)(\d{1,3})Deg[\s:]*(\d\d)?[\s:]*(\d\d)?[.,]?(\d*)?')
+    p2 = re.compile(r'([+-]?)(\d{1,3})[\s:]+(\d\d)?[\s:]*(\d\d)?[.,]?(\d*)?')
     p3 = re.compile(r'([+-]?)(\d{1,3})[.,]?(\d*)?')
     isP1 = p1.fullmatch(value) is not None
     isP2 = p2.fullmatch(value) is not None
@@ -454,9 +454,8 @@ def formatHstrToText(angle):
     :param angle:
     :return:
     """
-    sgn, h, m, s, frac = sexagesimalizeToInt(angle.hours, 0)
-    text = f'{h:02d} {m:02d} {s:02d}'
-    return text
+    formatStr = '{1:02}:{2:02}:{3:02}'
+    return angle.hstr(format=formatStr)
 
 
 def formatDstrToText(angle):
@@ -464,10 +463,8 @@ def formatDstrToText(angle):
     :param angle:
     :return:
     """
-    sgn, d, m, s, frac = sexagesimalizeToInt(angle.degrees, 0)
-    sign = '+' if sgn >= 0 else '-'
-    text = f'{sign}{d:02d} {m:02d} {s:02d}'
-    return text
+    formatStr = '{0:+>1}{1:02}:{2:02}:{3:02}'
+    return angle.dstr(format=formatStr)
 
 
 def formatLatToText(angle):
