@@ -10,7 +10,7 @@
 # Python-based Tool for interaction with the 10micron mounts
 # GUI with PyQT5 for python
 #
-# written in python3, (c) 2019-2021 by mworion
+# written in python3, (c) 2019-2022 by mworion
 #
 # Licence APL2.0
 #
@@ -21,7 +21,6 @@ import sys
 import logging
 import subprocess
 import platform
-import time
 
 # external packages
 
@@ -68,11 +67,30 @@ class Update:
 
         return line
 
+    def isVenv(self):
+        """
+        detects if the actual package is running in a virtual environment. this
+        should be the case in any situation as mw4 should be installed in a venv.
+
+        :return: status
+        """
+        hasReal = hasattr(sys, 'real_prefix')
+        hasBase = hasattr(sys, 'base_prefix')
+
+        status = hasReal or hasBase and sys.base_prefix != sys.prefix
+        self.log.debug(f'venv: [{status}], hasReal:[{hasReal}], hasBase:[{hasBase}]')
+        self.log.debug(f'venv path: [{os.environ.get("VIRTUAL_ENV", "")}]')
+        return status
+
     def runInstall(self, versionPackage=''):
         """
         :param versionPackage:   package version to install
         :return: success
         """
+        if not self.isVenv():
+            self.writer('Updater not running in an virtual environment', 2)
+            return False
+
         runnable = ['pip',
                     'install',
                     f'mountwizzard4=={versionPackage}',
@@ -135,7 +153,6 @@ class UpdateGUI:
     def __init__(self, runnable=None, version=None, x=0, y=0, colorSet=0):
         self.version = version
 
-        from PyQt5.QtTest import QTest
         from PyQt5.QtCore import Qt
         from PyQt5.QtGui import QIcon, QPixmap, QColor, QPainter
         from PyQt5.QtWidgets import QApplication, QPushButton, QVBoxLayout
@@ -144,7 +161,6 @@ class UpdateGUI:
         res.qInitResources()
         from gui.utilities.stylesQtCss import Styles
 
-        self.test = QTest
         self.update = Update(runnable=runnable, writer=self.writeText)
 
         QApplication.setAttribute(Qt.AA_ShareOpenGLContexts)
@@ -232,7 +248,6 @@ class UpdateGUI:
         self.writeText(text, 2)
         self.writeText('Restarting MountWizzard4...', 1)
         self.writeText('...this takes some seconds...', 1)
-        self.test.qWait(3000)
         self.update.restart(text)
         return True
 
@@ -243,7 +258,6 @@ class UpdateGUI:
         self.cancelButt.setEnabled(False)
         self.updateButt.setEnabled(False)
         self.writeText(f'Installing now version {self.version}', 1)
-        self.test.qWait(1000)
         suc = self.update.runInstall(self.version)
         if suc:
             text = f'Successfully installed {self.version}'
@@ -254,7 +268,6 @@ class UpdateGUI:
 
         self.writeText('Restarting MountWizzard4...', 1)
         self.writeText('...this takes some seconds...', 1)
-        self.test.qWait(3000)
         self.update.restart(text)
         return True
 
@@ -267,7 +280,6 @@ class UpdateCLI:
         self.update = Update(runnable=runnable, writer=self.writeText)
 
         self.writeText(f'Installing now version {self.version}', 1)
-        time.sleep(1)
         suc = self.update.runInstall(self.version)
         if suc:
             text = f'Successfully installed {self.version}'
